Introduction
============

PYPOWER is a power flow and optimal power flow (OPF) solver. Current features
include:

* DC and AC (Newton's method & Fast Decoupled) power flow and
* DC and AC optimal power flow (OPF)

PYPOWER is a translation of MATPOWER_  to the Python_ programming language
using SciPy_.

.. include:: ./link_names.txt
